@@ -1,4 +1,4 @@
-from .flask import FlaskJSONAPI
+from .flaskext import FlaskJSONAPI
 from .serializer import (JSONAPI, AttributeActions, RelationshipActions,
                          Permissions, attr_descriptor, relationship_descriptor,
                          permission_test)
